package cn.com.qmth.examcloud.exchange.outer.api.provider;

import java.io.File;
import java.io.IOException;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.commons.base.util.HttpClientUtil;
import cn.com.qmth.examcloud.commons.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.basic.api.StudentCloudService;
import cn.com.qmth.examcloud.exchange.outer.api.StudentOuterService;
import cn.com.qmth.examcloud.exchange.outer.api.request.SaveStudentReq;
import cn.com.qmth.examcloud.exchange.outer.api.response.SaveStudentResp;
import cn.com.qmth.examcloud.exchange.outer.service.FaceService;
import io.swagger.annotations.ApiOperation;

/**
 * 类注释
 *
 * @author WANGWEI
 * @date 2018年6月29日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
@RestController
@RequestMapping("${$rmp.cloud.exchange.outer}/student")
public class StudentOuterServiceProvider extends ControllerSupport implements StudentOuterService {

	private static final long serialVersionUID = -8252740695302763716L;

	@Autowired
	StudentCloudService studentCloudService;

	@Autowired
	private FaceService faceService;

	@Value("${$tempDir}")
	private String tempDir;

	@ApiOperation(value = "保存学生信息")
	@PostMapping("saveStudent")
	@Override
	public SaveStudentResp saveStudent(@RequestBody SaveStudentReq req) {
		trim(req);

		Long rootOrgId = req.getRootOrgId();

		cn.com.qmth.examcloud.core.basic.api.request.SaveStudentReq request = new cn.com.qmth.examcloud.core.basic.api.request.SaveStudentReq();
		request.setIdentityNumber(req.getIdentityNumber());
		request.setName(req.getName());
		request.setOrgCode(req.getOrgCode());
		request.setOrgId(req.getOrgId());
		request.setOrgName(req.getOrgName());
		request.setPhoneNumber(req.getPhoneNumber());
		request.setRemark(req.getRemark());
		request.setRootOrgId(req.getRootOrgId());
		request.setStudentCode(req.getStudentCode());

		cn.com.qmth.examcloud.core.basic.api.response.SaveStudentResp response = studentCloudService
				.saveStudent(request);

		String photoUrl = req.getPhotoUrl();
		if (StringUtils.isNotBlank(photoUrl)) {
			byte[] bs = HttpClientUtil.get(photoUrl);

			int lastIndexOf = photoUrl.lastIndexOf(".");
			if (0 > lastIndexOf) {
				throw new StatusException("EX-100002",
						"photoPath is not end with photo file suffix.");
			}
			String fileSuffix = photoUrl.substring(lastIndexOf);

			String fileName = System.currentTimeMillis() + fileSuffix;
			File temp = new File(
					tempDir + File.separator + "student_photo" + File.separator + fileName);

			try {
				FileUtils.writeByteArrayToFile(temp, bs);
			} catch (IOException e) {
				throw new StatusException("EX-100003", "文件读写失败");
			}

			faceService.processFace(rootOrgId, fileName, temp, req.getOperator());
		}

		SaveStudentResp resp = new SaveStudentResp();
		resp.setOrgId(response.getOrgId());
		resp.setOrgName(response.getOrgName());
		resp.setRootOrgId(response.getRootOrgId());
		resp.setStudentId(response.getStudentId());
		return resp;
	}

}
