package cn.com.qmth.examcloud.exchange.outer.service.impl;

import java.io.File;
import java.io.IOException;
import java.util.Locale;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.commons.base.logging.ExamCloudLog;
import cn.com.qmth.examcloud.commons.base.logging.ExamCloudLogFactory;
import cn.com.qmth.examcloud.commons.base.util.UrlUtil;
import cn.com.qmth.examcloud.exchange.outer.service.UpyunService;
import main.java.com.UpYun;

/**
 * 类注释
 *
 * @author WANGWEI
 * @date 2018年9月4日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
@Service
public class UpyunServiceImpl implements UpyunService {

	protected ExamCloudLog log = ExamCloudLogFactory.getLog(this.getClass());

	private final Object LOCK = new Object();

	private UpYun upyun;

	@Value("${$UpYun.bucketName}")
	private String bucketName;

	@Value("${$UpYun.userName}")
	private String userName;

	@Value("${$UpYun.password}")
	private String password;

	@Value("${$UpYun.studentPhotoUrlBasePath}")
	private String studentPhotoUrlBasePath;

	/**
	 * 方法注释
	 *
	 * @author WANGWEI
	 * @return
	 */
	private UpYun getUpyun() {
		if (null == upyun) {
			synchronized (LOCK) {
				if (null == upyun) {
					upyun = new UpYun(bucketName, userName, password);
				}
			}
		}
		return upyun;
	}

	@Override
	public String writeFile(Long rootOrgId, String identityNumber, String fileName, File file) {
		String photoPath = rootOrgId + "/" + UrlUtil.encode(identityNumber).toUpperCase(Locale.US)
				+ "/" + fileName;

		String filePath = "/student_base_photo" + "/" + photoPath;

		try {
			getUpyun().writeFile(filePath, file, true);
		} catch (IOException e) {
			log.error("[UpYun] fail to write file. filePath=" + filePath, e);
			throw new StatusException("EX-360001", "上传文件到UpYun失败", e);
		}

		String photoUrl = studentPhotoUrlBasePath + filePath;

		return photoUrl;
	}

}
